summaryrefslogtreecommitdiffstats
path: root/ctxopt.c
diff options
context:
space:
mode:
authorpgen <p.gen.progs@gmail.com>2019-10-05 18:23:35 +0200
committerpgen <p.gen.progs@gmail.com>2019-10-05 23:03:57 +0200
commit57750bd05493b0578ae19eff5553129a6df3557f (patch)
treef6a39df80616a1d6e2b0e7cf2d509a334fbf3b75 /ctxopt.c
parent0f41afe27e8009efcd31597f8828df6ae9ac75e0 (diff)
Reformat and fix some typos
Diffstat (limited to 'ctxopt.c')
-rw-r--r--ctxopt.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/ctxopt.c b/ctxopt.c
index 670c090..9e09f93 100644
--- a/ctxopt.c
+++ b/ctxopt.c
@@ -152,9 +152,9 @@ strpref(char * s1, char * s2);
static char *
xstrtok_r(char * str, const char * delim, char ** end);
-/* ************* */
-/* cop interface */
-/* ************* */
+/* **************** */
+/* ctxopt interface */
+/* **************** */
typedef struct opt_s opt_t;
typedef struct par_s par_t;
@@ -986,9 +986,9 @@ str2argv(char * str, char ** args, int max)
return nb_args;
}
-/* ****************** */
-/* cop implementation */
-/* ****************** */
+/* ********************* */
+/* ctxopt implementation */
+/* ********************* */
static int ctxopt_initialized = 0; /* cap_init has not yet been called */
@@ -2042,9 +2042,9 @@ init_opts(char * spec, ctx_t * ctx)
return 1;
}
/* ================================================= */
/* cop initialization function, must be called first */
/* ================================================= */
void
ctxopt_init(void)
{
@@ -2852,9 +2852,9 @@ ctxopt_analyze(int nb_words, char ** words, int * nb_rem_args,
}
}
else if (expect_par && *par_name != '-')
- break; /* a unexpected non parameter was seen, assume it is *
- | The end of parameters and the start of non cop managed *
- | command line arguments. */
+ break; /* a unexpected non parameter was seen, assume it is the end *
+ | of parameters and the start of non ctxopt managed command *
+ | line arguments. */
else if (expect_arg && *par_name != '-')
{
ll_node_t * cstr_node;
@@ -2042,9 +2042,9 @@ init_opts(char * spec, ctx_t * ctx)
return 1;
}
-/* ================================================= */
-/* cop initialization function, must be called first */
-/* ================================================= */
+/* ==================================================== */
+/* ctxopt initialization function, must be called first */
+/* ==================================================== */
void
ctxopt_init(void)